@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -38,7 +38,9 @@
 #include <DWindowManagerHelper>
 #include <DDialog>
 #include <DWidget>
-
+#ifdef DTKCORE_CLASS_DConfigFile
+#include <DConfig>
+#endif
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QObject>
@@ -47,13 +49,23 @@
 #include <QVBoxLayout>
 #include <QTimer>
 #include <unistd.h>
+
 #ifdef KF5_WAYLAND_FLAGE_ON
+#ifdef DWAYLAND_SUPPORT
 #include <DWayland/Client/connection_thread.h>
 #include <DWayland/Client/clientmanagement.h>
 #include <DWayland/Client/event_queue.h>
 #include <DWayland/Client/registry.h>
-#endif
+#else
+#include <KF5/KWayland/Client/connection_thread.h>
+#include <KF5/KWayland/Client/clientmanagement.h>
+#include <KF5/KWayland/Client/event_queue.h>
+#include <KF5/KWayland/Client/registry.h>
+#endif  // DWAYLAND_SUPPORT
+#endif  // KF5_WAYLAND_FLAGE_ON
+
 #include "event_monitor.h"
+
 #undef Bool
 
 DGUI_USE_NAMESPACE
@@ -325,6 +337,10 @@ public:
     //void delayScreenshot(double num);
     void fullScreenshot();
 
+    /**
+     * @brief fullScreenRecord 快捷启动全屏录制
+     */
+    void fullScreenRecord(const QString fileName = "");
     /**
      * @brief 截取顶层窗口
      */
@@ -365,6 +381,10 @@ signals:
     void stopRecordArm();
     void setUndoEnable(bool status);
     void microPhoneEnable(bool);
+    /**
+     * @brief saveClipboardComing 数据是否已传递到剪切板
+     */
+    void saveClipboardComing();
 public slots:
     void onExit();
     /**
@@ -402,6 +422,10 @@ public slots:
     void updateSideBarPos();
 
     void updateCameraWidgetPos();
+    /**
+     * @brief 多屏幕错位时修正工具栏坐标
+     */
+    QPoint getTwoScreenIntersectPos(QPoint rawPos);
     /**
      * @brief 切换截图功能或者录屏功能
      * @param shapeType : "record" or "shot"
@@ -548,6 +572,17 @@ public slots:
      * @param msg
      */
     void onLockScreenEvent(QDBusMessage msg);
+    /**
+     * @brief onSaveClipboardComing 监听剪切板的信号，确保数据已经传递到剪切板，应用才退出
+     * @param msg
+     */
+    void onSaveClipboardComing(const QByteArray &msg);
+
+    /**
+     * @brief onPowersource 监听电源管理界面，进入电源管理界面时会触发此信号槽
+     * @param flag
+     */
+    void onPowersource(bool flag);
 
     /**
      * @brief 打开截图录屏帮助文档并定位到滚动截图
@@ -831,6 +866,11 @@ protected:
      * @brief 采用线程循环监听文件（"/home/" + userName + "/.cache/deepin/deepin-screen-recorder/stopRecord.txt"）是否存在且内容是否为1
      */
     void whileCheckTempFileArm();
+
+    /**
+     * @brief getAllWindowsInfo 1070获取窗口信息的新接口
+     */
+    QVector<ClientManagement::WindowState> getAllWindowStates();
 #endif
     /**
      * @brief 启动截图录屏时检测是否是锁屏状态
@@ -1243,15 +1283,36 @@ private:
      * @brief 是否是锁屏状态
      */
     bool m_isLockedState = false;
+    bool m_isScreenResolutionChanged = false;
+
+    /**
+     * @brief m_isFullScreenRecord 快捷全屏录制
+     * 通过命令行deepin-screen-recorder --rf <filename>启动的全屏录制，未静默状态，不会显示任何相关提示
+     */
+    bool m_isFullScreenRecord = false;
+
+    /**
+     * @brief m_scrollShotOffsetWH 滚动截图时截图区域的宽高偏移量，防止滚动截图时截到捕捉区域的虚线框
+     */
+    int m_scrollShotOffsetWH =0;
+    /**
+     * @brief m_scrollShotOffsetXY 滚动截图时截图区域的左上角坐标偏移量，防止滚动截图时截到捕捉区域的虚线框
+     */
+    int m_scrollShotOffsetXY =0;
+
+    /**
+     * @brief m_isSaveClipboard 是否已经保存到剪切板
+     */
+    bool m_isSaveClipboard = false;
+
+    /**
+     * @brief m_toolbarLastPoint 工具栏位置改变后，上一次工具栏的位置
+     */
+    QPoint m_toolbarLastPoint;
     /**
      * @brief 当前光标的位置
      */
     QPoint m_currentCursor;
-
-    /**
-     * @brief m_isScreenResolutionChanged 屏幕分辨率是否改变
-     */
-    bool m_isScreenResolutionChanged = false;
 };
 
 #endif //MAINWINDOW_H
